pub type Vector3 = Vec3<f64>;Aliased Type
pub struct Vector3 {
pub data: ArrayStorage<f64, U3, U1>,
/* private fields */
}Fields
data: ArrayStorage<f64, U3, U1>The data storage that contains all the matrix components and informations about its number of rows and column (if needed).